@@ -3,7 +3,7 @@ from . import base
 
 class Any(base.RegexBase):
 
-    join_char = '|'
+    join_char = "|"
 
     def __init__(self, children):
         super(Any, self).__init__()
@@ -11,6 +11,5 @@ class Any(base.RegexBase):
 
     def _get_regex(self, ctx):
         return self.join_char.join(
-            self._to_hidden_group(_el)._get_regex(ctx)
-            for _el in self.children
+            self._to_hidden_group(_el)._get_regex(ctx) for _el in self.children
         )
